#Gnonlin-plugin isn't yet in maemos repository, so we compile it.

#file gnl/.libs/libgnl.so
#should say: gnl/.libs/libgnl.so: ELF 32-bit LSB shared object, ARM, version 1 (SYSV), not stripped

#copy it to /usr/lib/gstreamer-0.10

#and check is it founded:
#gst-inspect gnonlin


#If you can't compile it, there are precompiled version on pre_compiled_plugin.
#-Aapo Rantalainen

cd gnonlin
make
